@@ -5,13 +5,14 @@
 # datetime:2021-06-10 16:45
 # software: PyCharm
 import requests
+from setting import SURVEILLANCE_SYSTEM_DOMAIN, SURVEILLANCE_SYSTEM_TOKEN
 
 
 class MonitoringCenterService(object):
 
-    def __init__(self, url, token):
-        self.url = url
-        self.token = token
+    def __init__(self):
+        self.url = SURVEILLANCE_SYSTEM_DOMAIN
+        self.token = SURVEILLANCE_SYSTEM_TOKEN
 
     def collection_list(self):
         """
